@@ -138,15 +138,19 @@ setMethod(
     
     if(n >= 0 && n !=Inf){
       n = as.integer(n + 1)
+      if (n > 1000){n = 1000L; message("Info: n has been restricted to 1000 due to AWS Athena limitation")}
       tryCatch(result <- res@connection@ptr$Athena$get_query_results(QueryExecutionId = res@info$QueryExecutionId, MaxResults = n))
       
       output <- lapply(result$ResultSet$Rows, function(x) (sapply(x$Data, function(x) if(length(x) == 0 ) NA else x)))
-      dt <- rbindlist(output)
+      dt <- rbindlist(output, fill = TRUE)
       colnames(dt) <- as.character(unname(dt[1,]))
       rownames(dt) <- NULL
       return(dt[-1,])
     }
     
+    # Added data scan information when returning data from athena
+    message("Info: (Data scanned: ",data_scanned(result$QueryExecution$Statistics$DataScannedInBytes),")")
+    
     #create temp file
     File <- tempfile()
     on.exit(unlink(File))
@@ -159,19 +163,10 @@ setMethod(
     
     # return metadata of athena data types
     tryCatch(result_class <- res@connection@ptr$Athena$get_query_results(QueryExecutionId = res@info$QueryExecutionId,
-                                                                         MaxResults = as.integer(1)))
-    
-    Type2 <- Type <- AthenaToRDataType(result_class$ResultSet$ResultSetMetadata$ColumnInfo)
-    # Type2 is to handle issue with data.table fread 
-    Type2[Type2 %in% "POSIXct"] <- "character"
-    
+                                                                         MaxResults = as.integer(1))$ResultSet$ResultSetMetadata$ColumnInfo)
+
     if(grepl("\\.csv$",result_info$key)){
-      # currently parameter data.table is left as default. If users require data.frame to be returned then parameter will be updated
-      output <- data.table::fread(File, col.names = names(Type2), sep = ",", colClasses = unname(Type2), showProgress = F, na.strings="")
-      # formatting POSIXct: from string to POSIXct
-      for (col in names(Type[Type %in% "POSIXct"])) set(output, j=col, value=as.POSIXct(output[[col]]))
-      # AWS Athena returns " values as "". Due to this "" will be reformatted back to "
-      for (col in names(Type[Type %in% "character"])) set(output, j=col, value=gsub('""' , '"', output[[col]]))
+      output <- athena_read(athena_option_env$file_parser, File, result_class)
     } else{
       file_con <- file(File)
       output <- suppressWarnings(readLines(file_con))
