@@ -164,39 +164,14 @@ cred_set <- function(aws_access_key_id,
   config
 }
 
-# split data frame into batches
-split_data <- function(x, max.batch = Inf, path = tempdir(), sep = ",", compress = T, file.type = "csv"){
-  
-  # Bypass splitter if not compressed
-  if(!compress){
-    file <- paste(paste(sample(letters, 10, replace = TRUE), collapse = ""), Compress(file.type, compress), sep = ".")
-    path <- file.path(path, file)
-    fwrite(x, path,  quote = FALSE, sep = sep, showProgress = FALSE)
-    return(path)}
-  
-  # set up split vec
-  max_row <- nrow(x)
-  split_10 <- .05 * max_row # default currently set to 20 split: https://github.com/DyfanJones/RAthena/issues/36
-  min.batch = 1000000 # min.batch sized at 1M
-  
-  # if batch is set to default
-  if(is.infinite(max.batch)){
-    max.batch <- max(split_10, min.batch)
-    split_vec <- seq(1, max_row, max.batch)
-  }
-  
-  # if max.batch is set by user
-  if(!is.infinite(max.batch)) split_vec <- seq(1, max_row, as.integer(max.batch))
-  
-  sapply(split_vec, write_batch, dt = x, max.batch = max.batch,
-         max_row= max_row, path = path, sep = sep, 
-         compress=compress, file.type= file.type)
-}
-
-write_batch <- function(split_vec, dt, max.batch, max_row, path, sep, compress, file.type){
-  sample <- dt[split_vec:min(max_row,(split_vec+max.batch-1)),]
-  file <- paste(paste(sample(letters, 10, replace = TRUE), collapse = ""), Compress(file.type, compress), sep = ".")
-  path <- file.path(path, file)
-  fwrite(sample, path, quote = FALSE, sep = sep, showProgress = FALSE)
-  path
-}
\ No newline at end of file
+# Format DataScannedInBytes to a more readable format: 
+data_scanned <- 
+  function (x) {
+    standard <- "legacy"
+    base <- 1024
+    units_map <- c("B", "KB", "MB", "GB", "TB", "PB")
+    power <- if (x <= 0) 0L else min(as.integer(log(x, base = base)), length(units_map) - 1L)
+    unit <- units_map[power + 1L]
+    if (power == 0 && standard == "legacy") unit <- "Bytes"
+    paste(round(x/base^power, digits = 2), unit)
+  }
\ No newline at end of file
